@@ -9,15 +9,13 @@ import glob
 import json
 import os
 import copy
+from pathlib import Path
 import six
 import jsonschema
 import cfnlint.decode.cfn_yaml
 from cfnlint.version import __version__
 from cfnlint.helpers import REGIONS
-try:  # pragma: no cover
-    from pathlib import Path
-except ImportError:  # pragma: no cover
-    from pathlib2 import Path
+
 
 # pylint: disable=too-many-public-methods
 LOGGER = logging.getLogger('cfnlint')
@@ -354,7 +352,7 @@ class CliArgs(object):
             '-I', '--info', help='Enable information logging', action='store_true'
         )
         standard.add_argument(
-            '-f', '--format', help='Output Format', choices=['quiet', 'parseable', 'json', 'junit', 'pretty']
+            '-f', '--format', help='Output Format', choices=['quiet', 'parseable', 'json', 'junit', 'pretty', 'sarif']
         )
         standard.add_argument(
             '-l', '--list-rules', dest='listrules', default=False,
@@ -582,11 +580,7 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs, object):
         all_filenames = []
         ignore_templates = self._ignore_templates()
         for filename in filenames:
-            if sys.version_info >= (3, 5):
-                # pylint: disable=E1123
-                add_filenames = glob.glob(filename, recursive=True)
-            else:
-                add_filenames = glob.glob(filename)
+            add_filenames = glob.glob(filename, recursive=True)
             # only way to know of the glob failed is to test it
             # then add the filename as requested
             if not add_filenames:
@@ -614,11 +608,7 @@ class ConfigMixIn(TemplateArgs, CliArgs, ConfigFileArgs, object):
         # some shells don't expand * and configparser won't expand wildcards
         all_filenames = []
         for filename in filenames:
-            if sys.version_info >= (3, 5):
-                # pylint: disable=E1123
-                add_filenames = glob.glob(filename, recursive=True)
-            else:
-                add_filenames = glob.glob(filename)
+            add_filenames = glob.glob(filename, recursive=True)
             # only way to know of the glob failed is to test it
             # then add the filename as requested
             if not add_filenames:
