@@ -2,7 +2,6 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import sys
 import fnmatch
 import json
 import logging
@@ -313,20 +312,12 @@ def get_schema_value_types():
                     if '.'.join(names + [propname]) == 'AWS::OpsWorksCM::Server.CustomPrivateKey':
                         # one off exception to handle a weird parsing issue in python 2.7
                         continue
-                    if sys.version_info[0] == 2:
-                        # for python 2 strings can be unicode
-                        if isinstance(p, unicode):  #pylint: disable=undefined-variable
-                            try:
-                                p = p.decode('ascii')
-                            except:  #pylint: disable=bare-except
-                                continue
-                    else:
-                        # python 3 has the ability to test isascii
-                        # python 3.7 introduces is ascii so switching to encode
-                        try:
-                            p.encode('ascii')
-                        except UnicodeEncodeError:
-                            continue
+                    # python 3 has the ability to test isascii
+                    # python 3.7 introduces is ascii so switching to encode
+                    try:
+                        p.encode('ascii')
+                    except UnicodeEncodeError:
+                        continue
                     try:
                         if '\\p{' in p:
                             continue
